import _extends from '@babel/runtime/helpers/extends';
import _toConsumableArray from '@babel/runtime/helpers/toConsumableArray';
import _slicedToArray from '@babel/runtime/helpers/slicedToArray';
import _objectWithoutProperties from '@babel/runtime/helpers/objectWithoutProperties';
import React__default, { useState, useRef, useEffect } from 'react';
import SelectField from '../Select/index.js';
import { components } from 'react-select';
import CheckBox from '../CheckBox/index.js';
import ButtonBase from '../ButtonBase/index.js';
import SvgSearch from '../../assets/svgs/search.svg.js';
import './MultiSelect.scss.js';
import Text from '../Text/index.js';
import PropTypes from 'prop-types';
import useRunOnceWhenTruthy from '../../hooks/useRunOnceWhenTruthy.js';

var _excluded = ["children", "selectProps"];
var Option = function Option(props) {
  var _props$data, _props$data2;
  var label2 = props === null || props === void 0 ? void 0 : (_props$data = props.data) === null || _props$data === void 0 ? void 0 : _props$data.label2;
  return /*#__PURE__*/React__default.createElement("div", null, /*#__PURE__*/React__default.createElement(components.Option, props, /*#__PURE__*/React__default.createElement("div", {
    className: "Suc-multiLine-option"
  }, /*#__PURE__*/React__default.createElement(CheckBox, {
    className: 'Suc-multiselect-checkbox',
    checked: props.isSelected
  }), /*#__PURE__*/React__default.createElement("div", {
    className: 'Suc-labels'
  }, /*#__PURE__*/React__default.createElement(Text, {
    fontWeight: 600,
    className: 'Suc-first-line'
  }, props.label), label2 && /*#__PURE__*/React__default.createElement(Text, null, props === null || props === void 0 ? void 0 : (_props$data2 = props.data) === null || _props$data2 === void 0 ? void 0 : _props$data2.label2)))));
};
var allOption = {
  label: "All",
  label2: 'Select all',
  value: "*"
};
var ValueContainer = function ValueContainer(_ref) {
  var _selectProps$selectPr;
  var children = _ref.children,
    selectProps = _ref.selectProps,
    props = _objectWithoutProperties(_ref, _excluded);
  var currentValues = props.getValue();
  var optionName = selectProps === null || selectProps === void 0 ? void 0 : (_selectProps$selectPr = selectProps.selectProps) === null || _selectProps$selectPr === void 0 ? void 0 : _selectProps$selectPr.optionName;
  var text = "".concat(currentValues === null || currentValues === void 0 ? void 0 : currentValues.length, " ").concat(optionName, " selected");
  if (currentValues.some(function (val) {
    return val.value === allOption.value;
  })) {
    text = "All ".concat(optionName, " (").concat((currentValues === null || currentValues === void 0 ? void 0 : currentValues.length) - 1, ")");
  }
  var newChildren = [/*#__PURE__*/React__default.createElement(Text, {
    key: 0
  }, text), children[1]];
  return /*#__PURE__*/React__default.createElement(components.MultiValueLabel, props, newChildren);
};
var MenuList = function MenuList(props) {
  var _props$selectProps;
  var _props$selectProps$se = (_props$selectProps = props.selectProps) === null || _props$selectProps === void 0 ? void 0 : _props$selectProps.selectProps,
    textFilter = _props$selectProps$se.textFilter,
    setTextFilter = _props$selectProps$se.setTextFilter,
    onApplyClick = _props$selectProps$se.onApplyClick,
    onCancelClick = _props$selectProps$se.onCancelClick;
  return /*#__PURE__*/React__default.createElement("div", {
    className: 'Suc-multiselect-menu'
  }, /*#__PURE__*/React__default.createElement("div", {
    className: "Suc-search"
  }, /*#__PURE__*/React__default.createElement(SvgSearch, {
    className: 'Suc-search-icon'
  }), /*#__PURE__*/React__default.createElement(CustomSearch, {
    type: 'search',
    textFilter: textFilter,
    setTextFilter: setTextFilter,
    selectProps: props.selectProps
  })), /*#__PURE__*/React__default.createElement(components.MenuList, props), /*#__PURE__*/React__default.createElement("div", {
    className: "Suc-actions"
  }, /*#__PURE__*/React__default.createElement(ButtonBase, {
    className: "Suc-cancel",
    onClick: onCancelClick
  }, "Clear"), /*#__PURE__*/React__default.createElement(ButtonBase, {
    className: "Suc-apply",
    onClick: onApplyClick
  }, "Apply")));
};
var MultiSelect = function MultiSelect(props) {
  var _props$options;
  var optionName = props.optionName;
  var _useState = useState([]),
    _useState2 = _slicedToArray(_useState, 2),
    innerValue = _useState2[0],
    setInnerValue = _useState2[1];
  var _useState3 = useState(''),
    _useState4 = _slicedToArray(_useState3, 2),
    textFilter = _useState4[0],
    setTextFilter = _useState4[1];
  var _useState5 = useState(false),
    _useState6 = _slicedToArray(_useState5, 2),
    isFocused = _useState6[0],
    setIsFocused = _useState6[1];
  var _useState7 = useState(false),
    _useState8 = _slicedToArray(_useState7, 2),
    isMenuOpen = _useState8[0],
    setIsMenuOpen = _useState8[1];
  var containerRef = useRef(null);
  var options = (_props$options = props.options) !== null && _props$options !== void 0 && _props$options.length ? [allOption].concat(_toConsumableArray(props.options)) : [];
  var defaultValue = props.defaultValue || options;
  useRunOnceWhenTruthy(function () {
    setInnerValue(defaultValue);
  }, props.options);
  var onApplyClick = function onApplyClick() {
    setIsMenuOpen(false);
    props.onChange(innerValue.filter(function (_ref2) {
      var value = _ref2.value;
      return value !== allOption.value;
    }));
  };
  var onCancelClick = function onCancelClick() {
    setTextFilter('');
    setInnerValue(defaultValue);
  };
  useEffect(function () {
    var onDomClick = function onDomClick(e) {
      if (!containerRef.current.contains(e.target)) {
        onApplyClick();
      }
    };
    document.addEventListener("mousedown", onDomClick);
    return function () {
      document.removeEventListener("mousedown", onDomClick);
    };
  }, [innerValue]);
  return /*#__PURE__*/React__default.createElement("div", {
    ref: containerRef,
    className: "Suc-multi-select ".concat(props.className)
  }, /*#__PURE__*/React__default.createElement(SelectField, _extends({
    isMulti: true,
    closeMenuOnSelect: false,
    hideSelectedOptions: false,
    allowSelectAll: true,
    isSearchable: false,
    onMenuInputFocus: function onMenuInputFocus() {
      return setIsFocused(true);
    },
    onMenuOpen: function onMenuOpen() {
      return setIsMenuOpen(function (prev) {
        return !prev;
      });
    },
    onInputChange: function onInputChange(val) {
      return setTextFilter(val);
    },
    inputValue: textFilter,
    menuIsOpen: isMenuOpen,
    isFocused: isFocused || undefined,
    components: {
      Option: Option,
      MenuList: MenuList,
      ValueContainer: ValueContainer
    }
  }, props, {
    options: options,
    onChange: function onChange(selected, event) {
      if (selected !== null && selected.length > 0) {
        if (selected[selected.length - 1].value === allOption.value) {
          // if select all was clicked, select all options
          return setInnerValue(options);
        }
        var result = [];
        if (selected.length === props.options.length) {
          // if all options selected ony by one, selecting also 'select All' option
          if (selected.includes(allOption)) {
            // if all was selected and one option was deselected, deselect also 'select all option
            result = selected.filter(function (option) {
              return option.value !== allOption.value;
            });
          } else if (event.action === "select-option") {
            result = options;
          }
          return setInnerValue(result);
        }
      }
      return setInnerValue(selected);
    },
    value: innerValue,
    selectProps: {
      textFilter: textFilter,
      setTextFilter: setTextFilter,
      optionName: optionName,
      onApplyClick: onApplyClick,
      onCancelClick: onCancelClick
    }
  })));
};
var CustomSearch = function CustomSearch(_ref3) {
  var textFilter = _ref3.textFilter,
    setTextFilter = _ref3.setTextFilter,
    selectProps = _ref3.selectProps;
  var onMenuInputFocus = selectProps.onMenuInputFocus;
  return /*#__PURE__*/React__default.createElement("input", {
    className: 'Suc-search-text',
    autoCorrect: "off",
    autoComplete: "off",
    spellCheck: "false",
    type: "text",
    value: textFilter,
    onChange: function onChange(e) {
      return setTextFilter(e.currentTarget.value, {
        action: "input-change"
      });
    },
    onMouseDown: function onMouseDown(e) {
      e.stopPropagation();
      e.target.focus();
    },
    onTouchEnd: function onTouchEnd(e) {
      e.stopPropagation();
      e.target.focus();
    },
    onFocus: onMenuInputFocus,
    placeholder: "Search"
  });
};
var optionShape = {
  value: PropTypes.oneOfType([PropTypes.string, PropTypes.number]),
  label: PropTypes.node,
  label2: PropTypes.node
};
MultiSelect.propTypes = {
  /** custom classname */
  className: PropTypes.string,
  /** label */
  label: PropTypes.string,
  /** remove margin-bottom (to allow inline alignment) */
  removeBottomMargin: PropTypes.bool,
  /** options array */
  options: PropTypes.arrayOf(PropTypes.shape(optionShape)),
  /** default selected options */
  defaultValue: PropTypes.arrayOf(PropTypes.shape(optionShape)),
  /** show loader */
  isLoading: PropTypes.bool,
  /** Option name (all [optionName] selected) */
  optionName: PropTypes.string
};
MultiSelect.defaultProps = {
  className: '',
  disabled: false,
  removeBottomMargin: false,
  enableOptionsAdding: false,
  optionName: 'Options',
  defaultValue: null
};

export { MultiSelect as default };
//# sourceMappingURL=index.js.map
