import _slicedToArray from '@babel/runtime/helpers/slicedToArray';
import _defineProperty from '@babel/runtime/helpers/defineProperty';
import { useReducer, useRef, useCallback, useMemo } from 'react';
import _ from 'lodash';

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }
function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }
var init = function init(initialState) {
  return calculateIndices({
    stepsMap: initialState.stepsMap,
    stepPaths: initialState.stepPaths,
    currentStep: initialState.initialStep,
    currentStepPath: initialState.initialPath,
    previousStep: null,
    state: initialState.initialState || {}
  });
};
var calculateIndices = function calculateIndices(state) {
  var stepPaths = state.stepPaths,
    currentStepPath = state.currentStepPath,
    currentStep = state.currentStep,
    previousStep = state.previousStep;
  var currentStepIndex = _.findIndex(stepPaths[currentStepPath], {
    key: currentStep
  });
  var previousStepIndex = _.findIndex(stepPaths[currentStepPath], {
    key: previousStep
  });
  var showSteps = _.take(stepPaths[currentStepPath], currentStepIndex + 1);
  return _objectSpread(_objectSpread({}, state), {}, {
    currentStepIndex: currentStepIndex,
    previousStepIndex: previousStepIndex,
    showSteps: showSteps
  });
};
var reducer = function reducer(state, action) {
  var type = action.type,
    payload = action.payload;
  switch (type) {
    case "SET-STEP":
      {
        var step = payload.step;
        return calculateIndices(_objectSpread(_objectSpread({}, state), {}, {
          currentStep: step,
          previousStep: state.currentStep
        }));
      }
    case "SET-STEP-PATH":
      {
        var _step = payload.step,
          stepPath = payload.stepPath;
        return calculateIndices(_objectSpread(_objectSpread({}, state), {}, {
          currentStep: _step,
          previousStep: state.currentStep,
          currentStepPath: stepPath
        }));
      }
    case "SET-STATE":
      {
        var mergeState = payload.mergeState;
        return _objectSpread(_objectSpread({}, state), {}, {
          state: _objectSpread(_objectSpread({}, state.state), mergeState)
        });
      }
    case "RESET-STATE":
      {
        return _objectSpread(_objectSpread({}, state), {}, {
          state: {}
        });
      }
    case "GO-TO-PREVIOUS-STEP":
      {
        var _step2 = state.stepPaths[state.currentStepPath][state.currentStepIndex - 1].key;
        return calculateIndices(_objectSpread(_objectSpread({}, state), {}, {
          currentStep: _step2,
          previousStep: state.currentStep
        }));
      }
    case "GO-TO-NEXT-STEP":
      {
        var _step3 = state.stepPaths[state.currentStepPath][state.currentStepIndex + 1].key;
        return calculateIndices(_objectSpread(_objectSpread({}, state), {}, {
          currentStep: _step3,
          previousStep: state.currentStep
        }));
      }
  }
  return state;
};
var useWizardController = (function (_ref) {
  var stepsMap = _ref.stepsMap,
    stepPaths = _ref.stepPaths,
    initialStep = _ref.initialStep,
    initialPath = _ref.initialPath,
    initialState = _ref.initialState;
  var _useReducer = useReducer(reducer, {
      stepsMap: stepsMap,
      stepPaths: stepPaths,
      initialStep: initialStep,
      initialPath: initialPath,
      initialState: initialState
    }, init),
    _useReducer2 = _slicedToArray(_useReducer, 2),
    wizardState = _useReducer2[0],
    dispatch = _useReducer2[1];
  var currentStep = wizardState.currentStep,
    previousStep = wizardState.previousStep,
    currentStepPath = wizardState.currentStepPath,
    currentStepIndex = wizardState.currentStepIndex,
    previousStepIndex = wizardState.previousStepIndex,
    showSteps = wizardState.showSteps,
    state = wizardState.state;
  var stateRef = useRef(null);
  stateRef.current = state;
  var gotoPreviousStep = useCallback(function () {
    dispatch({
      type: "GO-TO-PREVIOUS-STEP"
    });
  }, [dispatch]);
  var setStep = useCallback(function (step) {
    dispatch({
      type: "SET-STEP",
      payload: {
        step: step
      }
    });
  }, [dispatch]);
  var setStepPath = useCallback(function (step, stepPath) {
    dispatch({
      type: "SET-STEP-PATH",
      payload: {
        step: step,
        stepPath: stepPath
      }
    });
  }, [dispatch]);
  var setState = useCallback(function (state) {
    dispatch({
      type: "SET-STATE",
      payload: {
        mergeState: state
      }
    });
  }, [dispatch]);
  var resetState = useCallback(function () {
    dispatch({
      type: "RESET-STATE"
    });
  }, [dispatch]);
  var goToNextStep = useCallback(function () {
    dispatch({
      type: "GO-TO-NEXT-STEP"
    });
  }, [dispatch]);
  var getState = useCallback(function () {
    return stateRef.current;
  }, []);
  return useMemo(function () {
    return {
      setStep: setStep,
      setStepPath: setStepPath,
      currentStep: currentStep,
      previousStep: previousStep,
      currentStepPath: currentStepPath,
      currentStepIndex: currentStepIndex,
      previousStepIndex: previousStepIndex,
      showSteps: showSteps,
      setState: setState,
      state: state,
      stepsMap: stepsMap,
      stepPaths: stepPaths,
      gotoPreviousStep: gotoPreviousStep,
      resetState: resetState,
      getState: getState,
      goToNextStep: goToNextStep
    };
  }, [setStep, setStepPath, currentStep, previousStep, currentStepPath, currentStepIndex, previousStepIndex, showSteps, setState, state, stepsMap, stepPaths, gotoPreviousStep, resetState, getState, goToNextStep]);
});

export { useWizardController as default };
//# sourceMappingURL=useWizardController.js.map
